==> nextcloud-27.1.7p0.tgz: nextcloud/apps/photos/l10n/pt_BR.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link público",
    "Photos" : "Fotos",
    "Your memories under your control" : "Suas memórias sob seu controle",
    "All media" : "Toda mídia",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Nesse dia",
    "Shared with you" : "Compartilhado com você",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configurações de fotos",
    "Mark selection as favorite" : "Marcar seleção como favorito",
    "Add selection to favorites" : "Adicionar seleção aos favoritos",
    "Remove selection from favorites" : "Remover seleção dos favoritos",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localização do álbum",
    "Back" : "Voltar",
    "Add collaborators" : "Adicionar colaboradores",
    "Save" : "Salvar",
    "Create album" : "Criar álbum",
    "Add to Album" : "Adicionar ao Álbum",
    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
    "Shared by" : "Compartilhado por",
    "Create a new album." : "Criar um novo álbum.",
    "Create new album" : "Criar novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
    "Search people or groups" : "Pesquisar pessoas ou grupos",
    "No recommendations. Start typing." : "Sem recomendações. Começe a digitar.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remova {collaboratorLabel} da lista de colaboradores",
    "Copy the public link" : "Copiar link público",
    "Public link copied!" : "Link público copiado!",
    "Copy public link" : "Copiar link público",
    "Delete the public link" : "Remover link público",
    "Create public link share" : "Criar compartilhamento de link público",
    "Share via public link" : "Compartilhar via link público",
    "Failed to fetch collaborators list." : "Falha ao buscar a lista de colaboradores.",
    "Failed to update album." : "Falha ao atualizar álbum.",
    "This collection does not exist" : "Esta coleção não existe",
    "An error occurred" : "Ocorreu um erro",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%nfoto não identificada","%nfotos não identificadas","%nfotos não identificadas"],
    "Favorite" : "Favorito",
    "Select image {imageName}" : "Selecionar imagem {imageName}",
    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
    "Go back" : "Voltar",
    "Back to {folder}" : "Voltar para {folder}",
    "Share this folder" : "Compartilhar esta pasta",
    "Dates" : "Datas",
    "Add to {destination}" : "Adicionar a {destionation}",
    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
    "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
    "Home" : "Início",
    "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
    "View" : "Exibição",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarque todos",
    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
    "Open actions menu" : "Abrir menu de ações",
    "Edit album details" : "Modificar detalhes do álbu",
    "Download all files in album" : "Baixar todos os arquivos do álbum",
    "Delete album" : "Remover álbum",
    "Download selected files" : "Baixar arquivos selecionados",
    "Remove selection from album" : "Remover seleção do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum ainda não possui fotos ou vídeos!",
    "Add photos to this album" : "Adicionar fotos a este álbum",
    "Add photos to {albumName}" : "Add photos to {albumName}",
    "Manage collaborators" : "Gerenciar colaboradores",
    "Save collaborators for this album." : "Salve os colaboradores deste álbum.",
    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
    "There is no album yet!" : "Ainda não há álbum!",
    "This person could not be found" : "Essa pessoa não pôde ser encontrada",
    "Rename person" : "Renomear pessoa",
    "Merge with different person" : "Unir com outra pessoa",
    "Download selected photos" : "Baixar fotos selecionadas",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remover pessoa",
    "Name of this person" : "Nome desta pessoa",
    "Save." : "Salvar.",
    "Merge person" : "Unir pessoa",
    "Move to different person" : "Ir para uma pessoa diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover fotos para outra pessoa","Mover fotos para outra pessoa","Mover fotos para outra pessoa"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remover fotos desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
    "This might take some time depending on the size of your photo library." : "Isso pode levar um tempo a depender do tamanho da sua biblioteca de fotos.",
    "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
    "This folder does not exist" : "Esta pasta não existe",
    "Loading folders …" : "Carregando pastas…",
    "No photos in here" : "Não há fotos aqui",
    "Taken on {date} at {time}" : "Tirada em {data} às {time}",
    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
    "Add photos to this place" : "Adicionar fotos a este espaço",
    "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
    "There is no place yet!" : "Ainda não há espaço!",
    "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
    "No tags yet" : "Ainda não há marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Adicionar",
    "Add to album" : "Adicionar a álbum",
    "Delete selection" : "Excluir seleção",
    "No photos or videos in here" : "Não há fotos ou vídeos aqui",
    "Unassigned faces" : "Rostos não identificados",
    "_%n photos_::_%n photos_" : ["%nfoto","%nfotos","%nfotos"],
    "Failed to fetch collection." : "Failed to fetch collection.",
    "Failed to fetch collections list." : "Failed to fetch collections list.",
    "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
    "All your media" : "Todas as suas mídias",
    "Album {title}" : "Álbum {título}",
    "Shared Albums" : "Álbuns Compartilhados",
    "Shared album {title}" : "Álbum compartilhado {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos marcadas",
    "Tagged photo {title}" : "Foto marcada {title}",
    "{title}'s face" : "rosto de {title}",
    "{startDate} to {endDate}" : "{startDate} até {endDate}",
    "Details" : "Detalhes",
    "Failed to rename {oldName} to {faceName}." : "Falha ao renomear {oldName} para {faceName}.",
    "Failed to delete {faceName}." : "Falha ao remover {faceName}.",
    "Failed to delete {fileId}." : "Falha ao excluir {fileId}.",
    "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
    "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
    "Go back to the previous view." : "Ir para a visualização anterior.",
    "Go to the add collaborators view." : "Ir para visualização de adicionar colaboradores.",
    "Create the album." : "Criar o álbum.",
    "Back to the new album form." : "Voltar ao formulário de novo álbum.",
    "_Share with %n user_::_Share with %n users_" : ["Compartilhar com %nusuário","Compartilhar com %nusuários","Compartilhar com %nusuários"],
    "Search for collaborators" : "Pesquisar colaboradores",
    "Add {collaboratorLabel} to the collaborators list" : "Adicionar {collaboratorsLabel} à lista de colaboradores",
    "No collaborators available" : "Nenhum colaborador disponível",
    "Failed to fetch album." : "Falha ao buscar álbum.",
    "The file is in the favorites" : "Esse arquivo está nos favoritos",
    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
    "Invalid location selected" : "Invalidar localização selecionada",
    "Photos directory" : "Diretório de fotos",
    "Add photos to the album" : "Adicionar fotos ao álbum",
    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
    "Shared albums" : "Álbuns compartilhados",
    "Create a new album" : "Criar um novo álbum",
    "Add selection to an album" : "Adicionar seleção a um álbu",
    "Failed to create {albumName}." : "Falha ao criar {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Falha ao renomear {currentAlbumName} para {newAlbumName}."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.11.tgz: nextcloud/apps/photos/l10n/pt_BR.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link público",
    "Photos" : "Fotos",
    "On This Day" : "Neste dia",
    "Your memories under your control" : "Suas memórias sob seu controle",
    "All media" : "Toda mídia",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Nesse dia",
    "Shared with you" : "Compartilhado com você",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configurações de fotos",
    "Mark selection as favorite" : "Marcar seleção como favorito",
    "Add selection to favorites" : "Adicionar seleção aos favoritos",
    "Remove selection from favorites" : "Remover seleção dos favoritos",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localização do álbum",
    "Back" : "Voltar",
    "Add collaborators" : "Adicionar colaboradores",
    "Save" : "Salvar",
    "Create album" : "Criar álbum",
    "Add to Album" : "Adicionar ao Álbum",
    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
    "Shared by" : "Compartilhado por",
    "Create a new album." : "Criar um novo álbum.",
    "Create new album" : "Criar novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
    "Search people or groups" : "Pesquisar pessoas ou grupos",
    "No recommendations. Start typing." : "Sem recomendações. Começe a digitar.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remova {collaboratorLabel} da lista de colaboradores",
    "Copy the public link" : "Copiar link público",
    "Public link copied!" : "Link público copiado!",
    "Copy public link" : "Copiar link público",
    "Delete the public link" : "Remover link público",
    "Create public link share" : "Criar compartilhamento de link público",
    "Share via public link" : "Compartilhar via link público",
    "Failed to fetch collaborators list." : "Falha ao buscar a lista de colaboradores.",
    "Failed to update album." : "Falha ao atualizar álbum.",
    "This collection does not exist" : "Esta coleção não existe",
    "An error occurred" : "Ocorreu um erro",
    "No picture for this day" : "Nenhuma foto para este dia",
    "Picture taken on this day will show up here." : "A foto tirada neste dia aparecerá aqui.",
    "More photos from this day" : "Mais fotos deste dia",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%nfoto não identificada","%nfotos não identificadas","%nfotos não identificadas"],
    "Favorite" : "Favorito",
    "Select image {imageName}" : "Selecionar imagem {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abra a imagem \"{name}\" em tamanho real",
    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
    "Open the \"{name}\" folder" : "Abra a pasta \"{nome}\"",
    "Go back" : "Voltar",
    "Back to {folder}" : "Voltar para {folder}",
    "Share this folder" : "Compartilhar esta pasta",
    "Dates" : "Datas",
    "Jump to specific date in list" : "Ir para uma data específica na lista",
    "Jump to {date}" : "Ir para {data}",
    "Add to {destination}" : "Adicionar a {destionation}",
    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
    "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
    "Delete source directory" : "Excluir diretório de origem",
    "All folders" : "Todas as pastas",
    "Add a Photos source for the timelines" : "Adicione uma fonte de fotos para os cronogramas",
    "Add folder" : "Adicionar pasta",
    "Select a source folder for your media" : "Selecione uma pasta de origem para sua mídia",
    "Home" : "Início",
    "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
    "Choose a different folder" : "Escolha uma pasta diferente",
    "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
    "View" : "Exibição",
    "Media folders" : "Pastas de mídia",
    "Choose the folders from where photos and videos are shown." : "Escolha as pastas onde as fotos e vídeos serão mostrados.",
    "Upload folder" : "Carregar pasta",
    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta para onde as fotos e os álbuns serão carregados.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarque todos",
    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
    "Open actions menu" : "Abrir menu de ações",
    "Edit album details" : "Modificar detalhes do álbu",
    "Download all files in album" : "Baixar todos os arquivos do álbum",
    "Delete album" : "Remover álbum",
    "Download selected files" : "Baixar arquivos selecionados",
    "Remove selection from album" : "Remover seleção do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum ainda não possui fotos ou vídeos!",
    "Add photos to this album" : "Adicionar fotos a este álbum",
    "Add photos to {albumName}" : "Add photos to {albumName}",
    "Manage collaborators" : "Gerenciar colaboradores",
    "Save collaborators for this album." : "Salve os colaboradores deste álbum.",
    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
    "There is no album yet!" : "Ainda não há álbum!",
    "This person could not be found" : "Essa pessoa não pôde ser encontrada",
    "Rename person" : "Renomear pessoa",
    "Merge with different person" : "Unir com outra pessoa",
    "Download selected photos" : "Baixar fotos selecionadas",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remover pessoa",
    "Name of this person" : "Nome desta pessoa",
    "Save." : "Salvar.",
    "Merge person" : "Unir pessoa",
    "Move to different person" : "Ir para uma pessoa diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover fotos para outra pessoa","Mover fotos para outra pessoa","Mover fotos para outra pessoa"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remover fotos desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
    "This might take some time depending on the size of your photo library." : "Isso pode levar um tempo a depender do tamanho da sua biblioteca de fotos.",
    "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
    "This folder does not exist" : "Esta pasta não existe",
    "Loading folders …" : "Carregando pastas…",
    "No photos in here" : "Não há fotos aqui",
    "Taken on {date} at {time}" : "Tirada em {data} às {time}",
    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
    "Add photos to this place" : "Adicionar fotos a este espaço",
    "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
    "There is no place yet!" : "Ainda não há espaço!",
    "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
    "No tags yet" : "Ainda não há marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "One of the source folders does not exists" : "Uma das pastas de origem não existe",
    "Add" : "Adicionar",
    "Add to album" : "Adicionar a álbum",
    "Delete selection" : "Excluir seleção",
    "No photos or videos in here" : "Não há fotos ou vídeos aqui",
    "Unassigned faces" : "Rostos não identificados",
    "_%n photos_::_%n photos_" : ["%nfoto","%nfotos","%nfotos"],
    "Failed to fetch collection." : "Failed to fetch collection.",
    "Failed to fetch collections list." : "Failed to fetch collections list.",
    "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
    "All your media" : "Todas as suas mídias",
    "Album {title}" : "Álbum {título}",
    "Shared Albums" : "Álbuns Compartilhados",
    "Shared album {title}" : "Álbum compartilhado {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos marcadas",
    "Tagged photo {title}" : "Foto marcada {title}",
    "{title}'s face" : "rosto de {title}",
    "{startDate} to {endDate}" : "{startDate} até {endDate}",
    "Details" : "Detalhes",
    "Failed to rename {oldName} to {faceName}." : "Falha ao renomear {oldName} para {faceName}.",
    "Failed to delete {faceName}." : "Falha ao remover {faceName}.",
    "Failed to delete {fileId}." : "Falha ao excluir {fileId}.",
    "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
    "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
    "Could not load photos folder" : "Não foi possível carregar a pasta de fotos",
    "Go back to the previous view." : "Ir para a visualização anterior.",
    "Go to the add collaborators view." : "Ir para visualização de adicionar colaboradores.",
    "Create the album." : "Criar o álbum.",
    "Back to the new album form." : "Voltar ao formulário de novo álbum.",
    "_Share with %n user_::_Share with %n users_" : ["Compartilhar com %nusuário","Compartilhar com %nusuários","Compartilhar com %nusuários"],
    "Search for collaborators" : "Pesquisar colaboradores",
    "Add {collaboratorLabel} to the collaborators list" : "Adicionar {collaboratorsLabel} à lista de colaboradores",
    "No collaborators available" : "Nenhum colaborador disponível",
    "Failed to fetch album." : "Falha ao buscar álbum.",
    "The file is in the favorites" : "Esse arquivo está nos favoritos",
    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
    "Invalid location selected" : "Invalidar localização selecionada",
    "Photos directory" : "Diretório de fotos",
    "Add photos to the album" : "Adicionar fotos ao álbum",
    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
    "Shared albums" : "Álbuns compartilhados",
    "Create a new album" : "Criar um novo álbum",
    "Add selection to an album" : "Adicionar seleção a um álbu",
    "Failed to create {albumName}." : "Falha ao criar {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Falha ao renomear {currentAlbumName} para {newAlbumName}."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
